from abc import ABC, abstractmethod
from typing import Optional
from ..database import db


class BaseSeeder(ABC):
    """数据种子基类"""

    @abstractmethod
    def run(self):
        """执行种子数据初始化"""
        pass

    def commit(self):
        """提交数据库事务"""
        db.session.commit()

    def rollback(self):
        """回滚数据库事务"""
        db.session.rollback()

    def execute(self):
        """执行种子数据初始化，包含事务处理"""
        try:
            self.run()
            self.commit()
            return True
        except Exception as e:
            self.rollback()
            raise e
