from .base_seeder import BaseSeeder
from ..models.dict_type_model import DictTypeModel
from ..models.dict_data_model import DictDataModel


class DictSeeder(BaseSeeder):
    """字典数据种子"""

    def run(self):
        # 初始化题目类型
        question_type = DictTypeModel(type_name='题目类型',
                                      type_code='question_type',
                                      description='题目类型字典',
                                      is_system=True)

        # 初始化题目难度
        question_difficulty = DictTypeModel(type_name='题目难度',
                                            type_code='question_difficulty',
                                            description='题目难度字典',
                                            is_system=True)

        # 初始化题目分类
        question_category = DictTypeModel(type_name='题目分类',
                                          type_code='question_category',
                                          description='题目分类字典',
                                          is_system=True)

        # 添加字典类型
        self._add_dict_types(
            [question_type, question_difficulty, question_category])

        # 初始化默认数据
        self._init_default_data(question_type, question_difficulty,
                                question_category)

    def _add_dict_types(self, dict_types):
        """添加字典类型"""
        for dict_type in dict_types:
            if not DictTypeModel.query.filter_by(
                    type_code=dict_type.type_code).first():
                self.session.add(dict_type)

    def _init_default_data(self, question_type, question_difficulty,
                           question_category):
        """初始化默认字典数据"""
        # 题目类型默认数据
        type_data = [
            {
                'label': '单选题',
                'value': 'single_choice'
            },
            {
                'label': '多选题',
                'value': 'multi_choice'
            },
            {
                'label': '判断题',
                'value': 'true_false'
            },
            {
                'label': '填空题',
                'value': 'fill_blank'
            },
            {
                'label': '简答题',
                'value': 'short_answer'
            },
        ]

        # 题目难度默认数据
        difficulty_data = [
            {
                'label': '简单',
                'value': 'easy'
            },
            {
                'label': '中等',
                'value': 'medium'
            },
            {
                'label': '困难',
                'value': 'hard'
            },
        ]

        # 添加题目类型数据
        self._add_dict_data(question_type, type_data)

        # 添加题目难度数据
        self._add_dict_data(question_difficulty, difficulty_data)

    def _add_dict_data(self, dict_type, data_list):
        """添加字典数据"""
        for data in data_list:
            if not DictDataModel.query.filter_by(dict_type_id=dict_type.id,
                                                 value=data['value']).first():
                self.session.add(
                    DictDataModel(dict_type_id=dict_type.id,
                                  label=data['label'],
                                  value=data['value']))
