import logger, data_seeder
from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from .middleware.auth_middleware import AuthMiddleware
from .middleware.exception_handler_middleware import ExceptionHandlerMiddleware
from .router import register_routers


def create_app() -> FastAPI:

    logger.info("欢迎使用智能题库系统后端API文档")

    # 初始化种子数据
    data_seeder.run_all_seeders()

    app = FastAPI(title="智能题库系统API",
                  description="智能题库系统后端API文档",
                  version="1.0.0")

    # 注册中间件
    def register_middlewares(app: FastAPI):
        # 异常处理中间件（最先注册）
        app.add_middleware(ExceptionHandlerMiddleware)

        # CORS中间件
        app.add_middleware(
            CORSMiddleware,
            allow_origins=["*"],
            allow_credentials=True,
            allow_methods=["*"],
            allow_headers=["*"],
        )

        # HTTP中间件（在路由之前注册）
        app.middleware("http")(AuthMiddleware.auth_required)

    # 注册路由
    app.include_router(register_routers())

    # 注册所有中间件
    register_middlewares(app)

    return app


if __name__ == '__main__':
    import uvicorn
    app = create_app()
    uvicorn.run(app, host="0.0.0.0", port=5000, log_level="info")
