from datetime import datetime
from sqlalchemy import Column, String, DateTime, ForeignKey
from sqlalchemy.orm import relationship
from .base_model import BaseModel


class Token(BaseModel):
    """认证令牌模型"""
    __tablename__ = "token"

    access_token = Column(String(512), nullable=False, comment="访问令牌")
    refresh_token = Column(String(512), nullable=False, comment="刷新令牌")
    token_type = Column(String(50), default="bearer", comment="令牌类型")
    expires_at = Column(DateTime, nullable=False, comment="过期时间")
    user_id = Column(Integer,
                     ForeignKey("user.id"),
                     nullable=False,
                     comment="用户ID")

    user = relationship("User", back_populates="tokens")


class TokenData(BaseModel):
    """令牌数据模型"""
    __tablename__ = "token_data"

    username = Column(String(255), nullable=True, comment="用户名")
    token_id = Column(Integer,
                      ForeignKey("token.id"),
                      nullable=False,
                      comment="关联令牌ID")

    token = relationship("Token", back_populates="token_data")
