from sqlalchemy import Column, Integer, String, Text, ForeignKey
from sqlalchemy.orm import relationship
from .base_model import BaseModel
from .question_knowledge_point import QuestionKnowledgePoint


class KnowledgePoint(BaseModel):
    """知识点模型"""
    __tablename__ = "knowledge_point"

    name = Column(String(255), nullable=False, comment="知识点名称")
    description = Column(Text, comment="知识点描述")
    parent_id = Column(Integer,
                       ForeignKey("knowledge_point.id"),
                       comment="父知识点ID")
    level = Column(Integer, default=1, comment="知识点层级")
    order = Column(Integer, default=0, comment="排序序号")
    status = Column(Integer, default=1, comment="状态 1:正常 0:禁用")

    # 关系定义
    questions = relationship("Question",
                             secondary="question_knowledge_point",
                             back_populates="knowledge_points")
    children = relationship("KnowledgePoint",
                            back_populates="parent",
                            remote_side=[parent_id])
    parent = relationship("KnowledgePoint",
                          back_populates="children",
                          remote_side=[parent_id])

    def __repr__(self):
        return f"<KnowledgePoint(id={self.id}, name={self.name})>"
