from ..models.base_model import BaseModel
from sqlalchemy import Column, String, Integer
from sqlalchemy.orm import relationship


class Role(BaseModel):
    """角色模型"""
    __tablename__ = 'roles'

    id = Column(Integer, primary_key=True, autoincrement=True)
    name = Column(String(50), unique=True, nullable=False)  # 角色名称
    description = Column(String(255))  # 角色描述
    is_default = Column(Integer, default=0)  # 是否为默认角色

    # 与用户的关联
    users = relationship('User',
                         secondary='user_roles',
                         back_populates='roles')

    # 与权限的关联
    permissions = relationship('Permission',
                               secondary='role_permissions',
                               back_populates='roles')

    def __repr__(self):
        return f"<Role(id={self.id}, name={self.name})>"
