from ..models.base_model import BaseModel
from sqlalchemy import Column, String, Integer, DateTime, ForeignKey
from sqlalchemy.orm import relationship
from datetime import datetime


class User(BaseModel):
    """用户模型"""
    __tablename__ = 'users'

    id = Column(Integer, primary_key=True, autoincrement=True)
    username = Column(String(50), unique=True, nullable=False)
    password_hash = Column(String(255), nullable=False)  # 密码哈希
    last_login = Column(DateTime)  # 最后登录时间
    is_active = Column(Integer, default=1)  # 是否激活
    created_at = Column(DateTime, default=datetime.now)  # 创建时间
    reset_token = Column(String(32))  # 密码重置token
    reset_token_expires = Column(DateTime)  # 重置token过期时间

    # 与角色的关联
    roles = relationship('Role',
                         secondary='user_roles',
                         back_populates='users')

    # 与用户统计信息的关联
    statistics = relationship('UserStatistics', back_populates='user')

    # 与认证令牌的关联
    tokens = relationship('Token', back_populates='user')

    def __repr__(self):
        return f"<User(id={self.id}, username={self.username})>"
