from ..database import db
from ..models import ExamPaper, ExamRecord, ExamScore, ExamAnalysis
from ..common.exceptions import BusinessException
from datetime import datetime
import json


class ExamService:

    def __init__(self):
        pass

    def create_exam_paper(self, creator_id, paper_data):
        """创建试卷"""
        try:
            paper = ExamPaper(name=paper_data['name'],
                              description=paper_data.get('description'),
                              duration=paper_data['duration'],
                              total_score=paper_data['total_score'],
                              difficulty=paper_data['difficulty'],
                              tags=json.dumps(paper_data.get('tags', [])),
                              creator_id=creator_id)
            db.session.add(paper)
            db.session.commit()
            return paper
        except Exception as e:
            db.session.rollback()
            raise BusinessException(f'创建试卷失败: {str(e)}')

    def start_exam(self, user_id, paper_id):
        """开始考试"""
        try:
            exam_record = ExamRecord(user_id=user_id,
                                     exam_paper_id=paper_id,
                                     start_time=datetime.now(),
                                     status='in_progress')
            db.session.add(exam_record)
            db.session.commit()
            return exam_record
        except Exception as e:
            db.session.rollback()
            raise BusinessException(f'开始考试失败: {str(e)}')

    def submit_exam(self, record_id, answers):
        """提交考试"""
        try:
            record = ExamRecord.query.get(record_id)
            if not record:
                raise BusinessException('考试记录不存在')

            record.end_time = datetime.now()
            record.status = 'completed'
            record.answers = json.dumps(answers)
            db.session.commit()

            # 触发成绩计算
            self.calculate_score(record_id)
            return record
        except Exception as e:
            db.session.rollback()
            raise BusinessException(f'提交考试失败: {str(e)}')

    def calculate_score(self, record_id):
        """计算考试成绩"""
        try:
            record = ExamRecord.query.get(record_id)
            if not record:
                raise BusinessException('考试记录不存在')

            # 这里实现具体的评分逻辑
            total_score = 100  # 示例分数
            score = ExamScore(user_id=record.user_id,
                              exam_record_id=record.id,
                              total_score=total_score)
            db.session.add(score)
            db.session.commit()
            return score
        except Exception as e:
            db.session.rollback()
            raise BusinessException(f'计算成绩失败: {str(e)}')

    def get_exam_analysis(self, record_id):
        """获取考试分析"""
        try:
            analysis = ExamAnalysis.query.filter_by(
                exam_record_id=record_id).first()
            if not analysis:
                raise BusinessException('考试分析不存在')
            return analysis
        except Exception as e:
            raise BusinessException(f'获取考试分析失败: {str(e)}')
