from ..models.user import User
from ..models.role import Role
from ..models.user_role import UserRole
from ..database import get_db


class UserStore:

    def __init__(self):
        self.db = get_db()

    def get_user_by_username(self, username: str) -> User:
        """根据用户名获取用户"""
        return self.db.query(User).filter_by(username=username).first()

    def create_user(self, user_data: dict) -> User:
        """创建用户"""
        user = User(username=user_data['username'],
                    password_hash=user_data['password_hash'],
                    created_at=user_data['created_at'])

        # 分配角色
        if 'roles' in user_data:
            roles = self.db.query(Role).filter(
                Role.name.in_(user_data['roles'])).all()
            user.roles.extend(roles)
        else:
            default_role = self.db.query(Role).filter_by(is_default=1).first()
            if default_role:
                user.roles.append(default_role)

        self.db.add(user)
        self.db.commit()
        self.db.refresh(user)
        return user

    def get_user_by_id(self, user_id: int) -> User:
        """根据ID获取用户"""
        return self.db.query(User).get(user_id)

    def update_user(self, user_id: int, update_data: dict) -> bool:
        """更新用户信息"""
        user = self.get_user_by_id(user_id)
        if not user:
            return False

        for key, value in update_data.items():
            setattr(user, key, value)

        self.db.commit()
        return True

    def get_user_by_reset_token(self, reset_token: str) -> User:
        """根据重置token获取用户"""
        return self.db.query(User).filter_by(reset_token=reset_token).first()
