import os
from ..logger.logger import Logger


def test_logger():
    # 测试日志文件路径
    test_log_path = "logs/test.log"

    # 如果存在先删除旧日志文件
    if os.path.exists(test_log_path):
        os.remove(test_log_path)

    # 配置logger
    Logger.get_logger().handlers.clear()  # 清除已有handler
    Logger._instance = None  # 重置单例
    Logger()._configure_logger({
        "level": "DEBUG",
        "console": False,
        "file": test_log_path
    })

    # 写入测试日志
    Logger.debug("This is a debug message")
    Logger.info("This is an info message")
    Logger.warning("This is a warning message")
    Logger.error("This is an error message")

    # 验证日志文件是否创建
    if not os.path.exists(test_log_path):
        print("Test failed: Log file not created")
        return False

    # 验证日志内容
    with open(test_log_path, "r") as f:
        content = f.read()
        if "debug message" not in content or "error message" not in content:
            print("Test failed: Log content incorrect")
            return False

    print("Test passed: Logger working correctly")
    return True


if __name__ == "__main__":
    test_logger()
